@@ -9,16 +9,19 @@ class JpsClient(BaseClient):
     def __init__(self, api_client: ApiClient):
         super().__init__(api_client)
 
-    def install(self, filename: str, env_name: str) -> None:
+    def install(self, filename: str, env_name: str) -> str:
         with open(filename) as file:
             manifest_content = file.read()
 
-            self._execute(
+            response = self._execute(
                 who_am_i(),
                 jps=manifest_content,
-                envName=env_name
+                envName=env_name,
+                skipNodeEmails=True,
             )
 
+            return response["successText"]
+
     def get_engine_version(self) -> str:
         response = self._execute(
             who_am_i()
